==> kdepim-4.14.7.tar.xz: kdepim-4.14.7/libkdepim/addressline/recentaddress/recentaddresswidget.h <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef RECENTADDRESSWIDGET_H
#define RECENTADDRESSWIDGET_H

#include <QWidget>
#include <kabc/addressee.h>
#include <QStringList>
class KConfig;
class KPushButton;
class QListWidget;
class KLineEdit;

namespace KPIM {
class RecentAddressWidget : public QWidget
{
    Q_OBJECT
public:
    explicit RecentAddressWidget(QWidget *parent = 0);
    ~RecentAddressWidget();

    void setAddresses( const QStringList &addrs );
    QStringList addresses() const;
    void addAddresses(KConfig *config);
    bool wasChanged() const;

private slots:
    void slotAddItem();
    void slotRemoveItem();
    void slotSelectionChanged();
    void slotTypedSomething(const QString&);

protected:
    void updateButtonState();
    bool eventFilter( QObject* o, QEvent* e );

private:
    KPushButton* mNewButton, *mRemoveButton;
    QListWidget *mListView;
    KLineEdit *mLineEdit;
    bool mDirty;
};
}
#endif // RECENTADDRESSWIDGET_H

==> kdepim-4.14.10.tar.xz: kdepim-4.14.10/libkdepim/addressline/recentaddress/recentaddresswidget.h <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef RECENTADDRESSWIDGET_H
#define RECENTADDRESSWIDGET_H

#include <QWidget>
#include <kabc/addressee.h>
#include <QStringList>
class KConfig;
class KPushButton;
class QListWidget;
class KLineEdit;

namespace KPIM {
class RecentAddressWidget : public QWidget
{
    Q_OBJECT
public:
    explicit RecentAddressWidget(QWidget *parent = 0);
    ~RecentAddressWidget();

    void setAddresses( const QStringList &addrs );
    void storeAddresses(KConfig *config);
    bool wasChanged() const;

private slots:
    void slotAddItem();
    void slotRemoveItem();
    void slotSelectionChanged();
    void slotTypedSomething(const QString&);

protected:
    void updateButtonState();
    bool eventFilter( QObject* o, QEvent* e );

private:
    KPushButton* mNewButton, *mRemoveButton;
    QListWidget *mListView;
    KLineEdit *mLineEdit;
    bool mDirty;
};
}
#endif // RECENTADDRESSWIDGET_H
